@@ -1,6 +1,3 @@
-#include <string.h>
-#include <stdlib.h>
-
 #include "base.h"
 #include "buffer.h"
 #include "array.h"
@@ -9,6 +6,9 @@
 
 #include "configfile.h"
 
+#include <string.h>
+#include <stdlib.h>
+
 /**
  * like all glue code this file contains functions which
  * are the external interface of lighttpd. The functions
@@ -49,7 +49,7 @@ int config_insert_values_internal(server *srv, array *ca, const config_values_t
 						buffer_copy_string_buffer(ds->value, ((data_string *)(da->value->data[j]))->value);
 						if (!da->is_index_key) {
 							/* the id's were generated automaticly, as we copy now we might have to renumber them
-							 * this is used to prepend server.modules by mod_indexfiles as it has to be loaded
+							 * this is used to prepend server.modules by mod_indexfile as it has to be loaded
 							 * before mod_fastcgi and friends */
 							buffer_copy_string_buffer(ds->key, ((data_string *)(da->value->data[j]))->key);
 						}
@@ -103,7 +103,6 @@ int config_insert_values_internal(server *srv, array *ca, const config_values_t
 					if (e != ds->value->ptr && !*e && l >=0 && l <= 65535) {
 						*((unsigned short *)(cv[i].destination)) = l;
 						break;
-
 					}
 				}
 
@@ -112,7 +111,37 @@ int config_insert_values_internal(server *srv, array *ca, const config_values_t
 				return -1;
 			}
 			default:
-				log_error_write(srv, __FILE__, __LINE__, "ssds", "unexpected type for key:", cv[i].key, du->type, "expected a integer, range 0 ... 65535");
+				log_error_write(srv, __FILE__, __LINE__, "ssds", "unexpected type for key:", cv[i].key, du->type, "expected a short integer, range 0 ... 65535");
+				return -1;
+			}
+			break;
+		case T_CONFIG_INT:
+			switch(du->type) {
+			case TYPE_INTEGER: {
+				data_integer *di = (data_integer *)du;
+
+				*((unsigned int *)(cv[i].destination)) = di->value;
+				break;
+			}
+			case TYPE_STRING: {
+				data_string *ds = (data_string *)du;
+
+				if (ds->value->ptr && *ds->value->ptr) {
+					char *e;
+					long l = strtol(ds->value->ptr, &e, 10);
+					if (e != ds->value->ptr && !*e && l >= 0) {
+						*((unsigned int *)(cv[i].destination)) = l;
+						break;
+					}
+				}
+
+
+				log_error_write(srv, __FILE__, __LINE__, "ssb", "got a string but expected an integer:", cv[i].key, ds->value);
+
+				return -1;
+			}
+			default:
+				log_error_write(srv, __FILE__, __LINE__, "ssds", "unexpected type for key:", cv[i].key, du->type, "expected an integer, range 0 ... 4294967295");
 				return -1;
 			}
 			break;
@@ -181,7 +210,7 @@ int config_insert_values_global(server *srv, array *ca, const config_values_t cv
 	return config_insert_values_internal(srv, ca, cv);
 }
 
-unsigned short sock_addr_get_port(sock_addr *addr) {
+static unsigned short sock_addr_get_port(sock_addr *addr) {
 #ifdef HAVE_IPV6
 	return ntohs(addr->plain.sa_family ? addr->ipv6.sin6_port : addr->ipv4.sin_port);
 #else
@@ -289,6 +318,10 @@ static cond_result_t config_check_cond_nocache(server *srv, connection *con, dat
 			default:
 				break;
 			}
+#if defined USE_OPENSSL && ! defined OPENSSL_NO_TLSEXT
+		} else if (!buffer_is_empty(con->tlsext_server_name)) {
+			l = con->tlsext_server_name;
+#endif
 		} else {
 			l = srv->empty_string;
 		}
