@@ -811,8 +811,14 @@ static int cgi_create_env(server *srv, connection *con, plugin_data *p, buffer *
 
 		if (!buffer_is_empty(con->server_name)) {
 			size_t len = con->server_name->used - 1;
-			char *colon = strchr(con->server_name->ptr, ':');
-			if (colon) len = colon - con->server_name->ptr;
+
+			if (con->server_name->ptr[0] == '[') {
+				const char *colon = strstr(con->server_name->ptr, "]:");
+				if (colon) len = (colon + 1) - con->server_name->ptr;
+			} else {
+				const char *colon = strchr(con->server_name->ptr, ':');
+				if (colon) len = colon - con->server_name->ptr;
+			}
 
 			cgi_env_add(&env, CONST_STR_LEN("SERVER_NAME"), con->server_name->ptr, len);
 		} else {
@@ -1288,6 +1294,15 @@ TRIGGER_FUNC(cgi_trigger) {
 #endif
 			break;
 		case -1:
+			if (errno == ECHILD) {
+				/* someone else called waitpid... remove the pid to stop looping the error each time */
+				log_error_write(srv, __FILE__, __LINE__, "s", "cgi child vanished, probably someone else called waitpid");
+
+				cgi_pid_del(srv, p, p->cgi_pid.ptr[ndx]);
+				ndx--;
+				continue;
+			}
+
 			log_error_write(srv, __FILE__, __LINE__, "ss", "waitpid failed: ", strerror(errno));
 
 			return HANDLER_ERROR;
