@@ -1,6 +1,3 @@
-#include <stdlib.h>
-#include <string.h>
-
 #include "base.h"
 #include "log.h"
 #include "buffer.h"
@@ -9,6 +6,9 @@
 
 #include "response.h"
 
+#include <stdlib.h>
+#include <string.h>
+
 /* plugin config for all request/connections */
 
 typedef struct {
@@ -215,7 +215,7 @@ URIHANDLER_FUNC(mod_setenv_uri_handler) {
 	return HANDLER_GO_ON;
 }
 
-REQUESTDONE_FUNC(mod_setenv_reset) {
+CONNECTION_FUNC(mod_setenv_reset) {
 	plugin_data *p = p_d;
 
 	UNUSED(srv);
@@ -230,6 +230,7 @@ REQUESTDONE_FUNC(mod_setenv_reset) {
 
 /* this function is called at dlopen() time and inits the callbacks */
 
+int mod_setenv_plugin_init(plugin *p);
 int mod_setenv_plugin_init(plugin *p) {
 	p->version     = LIGHTTPD_VERSION_ID;
 	p->name        = buffer_init_string("setenv");
@@ -239,7 +240,7 @@ int mod_setenv_plugin_init(plugin *p) {
 	p->set_defaults  = mod_setenv_set_defaults;
 	p->cleanup     = mod_setenv_free;
 
-	p->handle_request_done  = mod_setenv_reset;
+	p->connection_reset  = mod_setenv_reset;
 
 	p->data        = NULL;
 
