@@ -1,8 +1,3 @@
-#include <ctype.h>
-#include <stdlib.h>
-#include <string.h>
-#include <errno.h>
-
 #include "base.h"
 #include "log.h"
 #include "buffer.h"
@@ -10,9 +5,10 @@
 
 #include "plugin.h"
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
+#include <ctype.h>
+#include <stdlib.h>
+#include <string.h>
+#include <errno.h>
 
 typedef struct {
 	buffer *server_root;
@@ -270,6 +266,7 @@ static handler_t mod_simple_vhost_docroot(server *srv, connection *con, void *p_
 }
 
 
+int mod_simple_vhost_plugin_init(plugin *p);
 int mod_simple_vhost_plugin_init(plugin *p) {
 	p->version     = LIGHTTPD_VERSION_ID;
 	p->name        = buffer_init_string("simple_vhost");
