@@ -409,19 +409,31 @@ static void show_features (void) {
       "\t- libev (generic)\n"
 #endif
       "\nNetwork handler:\n\n"
-#if defined(USE_LINUX_SENDFILE) || defined(USE_FREEBSD_SENDFILE) || defined(USE_SOLARIS_SENDFILEV) || defined(USE_AIX_SENDFILE)
-      "\t+ sendfile\n"
+#if defined USE_LINUX_SENDFILE
+      "\t+ linux-sendfile\n"
 #else
-  #ifdef USE_WRITEV
+      "\t- linux-sendfile\n"
+#endif
+#if defined USE_FREEBSD_SENDFILE
+      "\t+ freebsd-sendfile\n"
+#else
+      "\t- freebsd-sendfile\n"
+#endif
+#if defined USE_SOLARIS_SENDFILEV
+      "\t+ solaris-sendfilev\n"
+#else
+      "\t- solaris-sendfilev\n"
+#endif
+#if defined USE_WRITEV
       "\t+ writev\n"
-  #else
+#else
+      "\t- writev\n"
+#endif
       "\t+ write\n"
-  #endif
-  #ifdef USE_MMAP
+#ifdef USE_MMAP
       "\t+ mmap support\n"
-  #else
+#else
       "\t- mmap support\n"
-  #endif
 #endif
       "\nFeatures:\n\n"
 #ifdef HAVE_IPV6
@@ -570,6 +582,13 @@ int main (int argc, char **argv) {
 	while(-1 != (o = getopt(argc, argv, "f:m:hvVDpt"))) {
 		switch(o) {
 		case 'f':
+			if (srv->config_storage) {
+				log_error_write(srv, __FILE__, __LINE__, "s",
+						"Can only read one config file. Use the include command to use multiple config files.");
+
+				server_free(srv);
+				return -1;
+			}
 			if (config_read(srv, optarg)) {
 				server_free(srv);
 				return -1;
